@@ -1,4 +1,5 @@
 # General, Copyright (c) 2001-2003 by David R. Bickel.
+# Last modified by David R. Bickel on 3/25/04.
 # Created by David R. Bickel on 10/1/01. 
 # 8/7/02. 'clip' changed to 'crop' throughout.
 # 8/2/02. data.frame.as.matrices and matrices.as.data.frame added.
@@ -486,7 +487,7 @@ random.matrix <- function(ncases, means, standard.deviations = rep(1, length(mea
 }
 
 random.null.default <- function(n){rnorm(n, mean = 0, sd = 1)}
-random.alt.default <- function(n){(if(rbern(n = 1, prob = .5)) 1 else -1) * rnorm(n, mean = 2, sd = 1)}
+random.alt.default <- function(n, mean = 2){(if(rbern(n = 1, prob = .5) == 1) 1 else -1) * rnorm(n, mean = mean, sd = 1)}
 
 data.from.mixture <- function(probs.alt, sample.size, random.null = random.null.default, random.alt = random.alt.default)
 {
@@ -571,8 +572,14 @@ eval.arg <- function(..., print.cmd = FALSE)
 add.quotes <- function(file.or.folder = 'temp.r'){paste('"', file.or.folder, '"', sep = '')}
 cat.unix <- function(file.or.folder = 'temp.r', intern = FALSE, ...)
 { system(paste('cat', file.or.folder), intern = intern, ...)}
-open.unix <- function(file.or.folder = 'temp.r', intern = FALSE, ...)
-{ system(paste('open', add.quotes(file.or.folder)), intern = intern, ...)}
+open.unix <- function(file.or.folder = 'temp.r', intern = FALSE, available = (version$arch == 'powerpc'), ...)
+{ 
+  cmd <- paste('open', add.quotes(file.or.folder))
+  if(available)
+    system(cmd, intern = intern, ...)
+  else
+    cool.cat('The following system call was supressed due to uncertainty of its availability on non-PowerPC architectures:\n', cmd)
+}
 new.file.unix <- function(file = 'temp.r', intern = FALSE, ...)
 {
   first.line <- paste('', file, ' created by new.file.unix on ', date(), '.\n', sep = '')
